# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'

%define _with_repolib 1

%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/oswego-concurrent/%{version}.%{reltag}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define gcj_support %{?_with_gcj_support:1}%{!?_with_gcj_support:%{?_without_gcj_support:0}%{!?_without_gcj_support:%{?_gcj_support:%{_gcj_support}}%{!?_gcj_support:0}}}

%define section free

%define reltag  patch01

Name:           concurrent
Version:        1.3.4
Release:        9%{?dist}
Epoch:          0
Summary:        Utility classes for concurrent Java programming
License:        Public Domain
Source0:        http://gee.cs.oswego.edu/dl/classes/EDU/oswego/cs/dl/current/concurrent-1.3.4-src.tar.gz
# Source1 not used, kept for reference
Source1:        %{name}-%{version}.build.xml

Source2:	concurrent-component-info.xml
Source3:	concurrent-README.txt
Source4:        concurrent-1.3.4.pom
Patch0:		concurrent-build.patch
# This effectively fixes the oswego library.
# Several defects were found, including an unthreadsafe call to toArray()
Patch1:		concurrent-ConcurrentHashMap.patch
Patch2:		concurrent-ConcurrentReaderHashMap.patch
Patch3:		concurrent-PooledExecutor.patch
URL:            http://gee.cs.oswego.edu/dl/classes/EDU/oswego/cs/dl/util/concurrent/
Group:          Development/Libraries/Java
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  java-devel
BuildRequires:  ant
BuildRequires:  /bin/bash
BuildRequires:  zip
%if %{gcj_support}
BuildRequires:       java-gcj-compat-devel
%else
BuildArch:      noarch
%endif

%description 
This package provides standardized, efficient versions of utility classes
commonly encountered in concurrent Java programming. This code consists of
implementations of ideas that have been around for ages, and is merely intended
to save you the trouble of coding them. Discussions of the rationale and
applications of several of these classes can be found in the second edition of
Concurrent Programming in Java.

%if %{with_repolib}
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:	        Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -c

mkdir -p src/EDU/oswego/cs/dl/util
mv concurrent src/EDU/oswego/cs/dl/util

# Build with debug on
pushd src/EDU/oswego/cs/dl/util/concurrent
%patch0 -p0
popd

%patch1 -p0
%patch2 -p0
%patch3 -p0

# Pack sources in a proper way for loading into Eclipse
# Note that the sources for Eclipse contain the patches already
pushd src
find . -name "*.java" -print | zip ../concurrent-src.zip -@
popd
zip -d concurrent-src.zip EDU/oswego/cs/dl/util/concurrent/taskDemo/\*

sed -i 's/@VERSION@/%{version}.%{reltag}-brew/g' %{SOURCE2}
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{SOURCE2}

%build
pushd src/EDU/oswego/cs/dl/util/concurrent

ant \
  -Dversion=%{version} \
  -Dj2se.apiurl=%{_javadocdir}/java \
  dist javadoc

popd

%install
rm -fr $RPM_BUILD_ROOT
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
pwd
ls
install -m 644 src/EDU/oswego/cs/dl/util/concurrent/lib/%{name}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
ln -s %{name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr src/EDU/oswego/cs/dl/util/concurrent/docs/* \
       $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

# poms
%add_to_maven_depmap concurrent concurrent %{version} JPP %{name}
%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -a %{SOURCE4} %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom

%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -m 755 %{SOURCE2} $RPM_BUILD_ROOT%{repodir}/component-info.xml
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE3} $RPM_BUILD_ROOT%{repodirsrc}/README.txt
	install -m 755 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH1} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH2} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH3} $RPM_BUILD_ROOT%{repodirsrc}
	cp $RPM_BUILD_ROOT%{_javadir}/%{name}.jar $RPM_BUILD_ROOT%{repodirlib}
	cp concurrent-src.zip $RPM_BUILD_ROOT%{repodirlib}
%endif

%if %{gcj_support}
export CLASSPATH=$(build-classpath gnu-crypto)
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif
%update_maven_depmap

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%{_javadir}/*.jar
%if %{gcj_support}
%attr(-,root,root) %{_libdir}/gcj/%{name}/concurrent-1.3.4.jar.*
%endif
%{_datadir}/maven2/*
%{_mavendepmapfragdir}/*

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif

%changelog
* Tue Aug 26 2008 David Walluck <dwalluck@redhat.com> 0:1.3.4-9
- add pom

* Wed May 28 2008 Permaine Cheung <pcheung@redhat.com> - 0:1.3.4-8
- First JPP 5 build

* Wed Jan 23 2008 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-7jpp.ep1.6
- The source aip for Eclipse must have the patches applied

* Wed Jan 23 2008 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-7jpp.ep1.5
- Remove src from source tar ball path

* Wed Jan 23 2008 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-7jpp.ep1.4
- Actually apply patch

* Wed Jan 23 2008 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-7jpp.ep1.3
- Add missing PooledExecutor patch

* Wed Jan 23 2008 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-7jpp.ep1.2
- Add source zip file
- Strip prefix from README file name

* Mon Jan 21 2008 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-7jpp.ep1.1
- Add patches for JBAS-4698

* Mon May 21 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.3.4-7jpp
- Make Vendor, Distribution based on macro
- Fix aot build
- Rebuild using java-1.4.2

* Fri Mar 23 2007 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-6jpp.ep1.2
- Rebuild to get the proper tag in component-info.xml

* Fri Mar 23 2007 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-6jpp.ep1.1
- Merge with upstream for fixes in the build

* Fri Mar 23 2007 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-6jpp
- Use provided build.xml

* Tue Mar 13 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.3.4-1jpp.ep1.2
- Fix repolib location

* Tue Mar 13 2007 Fernando Nasser <fnasser@redhat.com> 0:1.3.4-1jpp.ep1.1
- New repolib location

* Mon Feb 19 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.3.4-1jpp.el4ep1.2
- Add -brew suffix

* Fri Feb 16 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.3.4-1jpp.el4ep1.1
- Add repolib support
- Use build.xml from upstream to produce a standard jar

* Fri Jan 26 2007 Permaine Cheung <pcheung at redhat.com> - 0:1.3.4-5jpp
- rpmlint cleanup

* Thu Aug 03 2006 Matt Wringe <mwringe at redhat.com> - 0:1.3.4-4jpp
- Add missing requires for javadoc task
- Add missing postun for javadoc task

* Thu Jul 20 2006 Matt Wringe <mwringe at redhat.com> - 0:1.3.4-3jpp
- Added conditional native compiling

* Thu Apr 27 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.3.4-2jpp
- First JPP 1.7 build

* Tue Jul 26 2005 Fernando Nasser <fnasser@redhat.com> 0:1.3.4-1jpp_1rh
- Merge with upstream

* Thu Dec 23 2004 Sebastiano Vigna <vigna@acm.org> 0:1.3.4-1jpp
- New release.

* Tue Nov 23 2004 Fernando Nasser <fnasser@redhat.com> 0:1.3.2-2jpp_2rh
- Rebuild

* Fri Aug 20 2004 Ralph Apel <r.apel at r-apel.de> 0:1.3.2-3jpp
- Build with ant-1.6.2

* Thu Mar  4 2004 Frank Ch. Eigler <fche@redhat.com> 0:4.1.29-2jpp_1rh
- RH vacuuming

* Wed Nov 19 2003 Sebastiano Vigna <vigna@acm.org> 0:1.3.2-2jpp
- Package name restored to EDU.

* Wed Nov 19 2003 Sebastiano Vigna <vigna@acm.org> 0:1.3.2-1jpp
- First JPackage version
